# Notification Manager

The module that is responsible for managing the notifications over time & enabling callbacks to be executed.

::: mac_notifications.manager.NotificationManager

::: mac_notifications.manager.CallbackExecutorThread
